==> hyperstream-0.2.6.tar.gz: hyperstream-0.2.6/hyperstream/__init__.py <==
# The MIT License (MIT) # Copyright (c) 2014-2017 University of Bristol
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
#  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
#  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
#  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
#  DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
#  OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
#  OR OTHER DEALINGS IN THE SOFTWARE.

from client import Client
from config import HyperStreamConfig
from plate import PlateManager
from workflow import Workflow, WorkflowManager
from channels import ChannelManager
from hyperstream import HyperStream  # , HyperStreamLogger
from online_engine import OnlineEngine
from stream import StreamId, Stream, StreamInstance, StreamMetaInstance, DatabaseStream, StreamDict, \
    StreamInstanceCollection, StreamView
from time_interval import TimeInterval, TimeIntervals, RelativeTimeInterval
from tool import Tool
from utils import MIN_DATE, UTC, StreamNotAvailableError, StreamAlreadyExistsError, StreamDataNotAvailableError, \
    StreamNotFoundError, IncompatiblePlatesError, ToolNotFoundError, ChannelNotFoundError, ToolExecutionError, \
    ChannelAlreadyExistsError, FactorAlreadyExistsError, FactorDefinitionError, LinkageError, \
    NodeAlreadyExistsError, PlateDefinitionError, PlateEmptyError, MultipleStreamsFoundError
from version import __version__

==> hyperstream-0.3.4.tar.gz: hyperstream-0.3.4/hyperstream/__init__.py <==
# The MIT License (MIT) # Copyright (c) 2014-2017 University of Bristol
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
#  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
#  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
#  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
#  DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
#  OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
#  OR OTHER DEALINGS IN THE SOFTWARE.

from .client import Client
from .config import HyperStreamConfig
from .plate import PlateManager
from .workflow import Workflow, WorkflowManager
from .channels import ChannelManager
from .hyperstream import HyperStream
from .online_engine import OnlineEngine
from .stream import StreamId, Stream, StreamInstance, StreamMetaInstance, DatabaseStream, StreamDict, \
    StreamInstanceCollection, StreamView
from .time_interval import TimeInterval, TimeIntervals, RelativeTimeInterval
from .tool import Tool, MultiOutputTool, AggregateTool, SelectorTool, PlateCreationTool
from .utils import MIN_DATE, UTC, StreamNotAvailableError, StreamAlreadyExistsError, StreamDataNotAvailableError, \
    StreamNotFoundError, IncompatiblePlatesError, ToolNotFoundError, ChannelNotFoundError, ToolExecutionError, \
    ChannelAlreadyExistsError, FactorAlreadyExistsError, FactorDefinitionError, LinkageError, \
    NodeAlreadyExistsError, PlateDefinitionError, PlateEmptyError, MultipleStreamsFoundError
from .version import __version__
